@@ -135,7 +135,8 @@ class SessionKeywords(RequestsKeywords):
 
         ``timeout`` Connection timeout
 
-        ``proxies`` Dictionary that contains proxy urls for HTTP and HTTPS communication
+        ``proxies`` Dictionary mapping protocol or protocol and host to the URL of the proxy
+                (e.g. {'http': 'foo.bar:3128', 'http://host.name': 'foo.bar:4012'})
 
         ``verify`` Whether the SSL cert will be verified. A CA_BUNDLE path can also be provided.
 
@@ -217,7 +218,8 @@ class SessionKeywords(RequestsKeywords):
 
         ``timeout`` Connection timeout
 
-        ``proxies`` Dictionary that contains proxy urls for HTTP and HTTPS communication
+        ``proxies`` Dictionary mapping protocol or protocol and host to the URL of the proxy
+                (e.g. {'http': 'foo.bar:3128', 'http://host.name': 'foo.bar:4012'})
 
         ``verify`` Whether the SSL cert will be verified. A CA_BUNDLE path can also be provided.
                  Defaults to False.
@@ -303,7 +305,8 @@ class SessionKeywords(RequestsKeywords):
 
         ``timeout`` Connection timeout
 
-        ``proxies`` Dictionary that contains proxy urls for HTTP and HTTPS communication
+        ``proxies`` Dictionary mapping protocol or protocol and host to the URL of the proxy
+                (e.g. {'http': 'foo.bar:3128', 'http://host.name': 'foo.bar:4012'})
 
         ``verify`` Whether the SSL cert will be verified. A CA_BUNDLE path can also be provided.
                  Defaults to False.
@@ -384,7 +387,8 @@ class SessionKeywords(RequestsKeywords):
 
         ``timeout`` Connection timeout
 
-        ``proxies`` Dictionary that contains proxy urls for HTTP and HTTPS communication
+        ``proxies`` Dictionary mapping protocol or protocol and host to the URL of the proxy
+                (e.g. {'http': 'foo.bar:3128', 'http://host.name': 'foo.bar:4012'})
 
         ``verify`` Whether the SSL cert will be verified. A CA_BUNDLE path can also be provided.
                  Defaults to False.
@@ -462,7 +466,8 @@ class SessionKeywords(RequestsKeywords):
 
         ``timeout`` Connection timeout
 
-        ``proxies`` Dictionary that contains proxy urls for HTTP and HTTPS communication
+        ``proxies`` Dictionary mapping protocol or protocol and host to the URL of the proxy
+                (e.g. {'http': 'foo.bar:3128', 'http://host.name': 'foo.bar:4012'})
 
         ``verify`` Whether the SSL cert will be verified. A CA_BUNDLE path can also be provided.
                  Defaults to False.
